@@ -1,32 +1,32 @@
 # SPDX-FileCopyrightText: 2022 James R. Barlow
 # SPDX-License-Identifier: MPL-2.0
 
-"""A library for manipulating PDFs
+"""A library for manipulating PDFs."""
 
-isort:skip_file
-"""
+# isort:skip_file
+
+from __future__ import annotations
+
+from pikepdf._version import __version__
 
 try:
-    from . import _qpdf
+    from pikepdf import _core
 except ImportError as _e:  # pragma: no cover
     _msg = "pikepdf's extension library failed to import"
     raise ImportError(_msg) from _e
 
-try:
-    from ._version import __version__
-except ImportError as _e:  # pragma: no cover
-    raise ImportError("Failed to determine version") from _e
-
-from ._qpdf import (
+from pikepdf._core import (
     AccessMode,
     Annotation,
     AttachedFileSpec,
     ContentStreamInlineImage,
     ContentStreamInstruction,
     DataDecodingError,
+    DeletedObjectError,
     ForeignObjectError,
     Job,
     JobUsageError,
+    Matrix,
     NameTree,
     NumberTree,
     ObjectHelper,
@@ -41,8 +41,12 @@ from ._qpdf import (
     TokenFilter,
     TokenType,
 )
-
-from .objects import (
+from pikepdf.exceptions import (
+    DependencyError,
+    OutlineStructureError,
+    UnsupportedImageTypeError,
+)
+from pikepdf.objects import (
     Array,
     Dictionary,
     Name,
@@ -52,36 +56,34 @@ from .objects import (
     Stream,
     String,
 )
-
-from .models import (
+from pikepdf.models import (
     Encryption,
     Outline,
     OutlineItem,
-    OutlineStructureError,
     PageLocation,
     PdfImage,
     PdfInlineImage,
-    PdfMatrix,
     Permissions,
-    UnsupportedImageTypeError,
     make_page_destination,
     parse_content_stream,
     unparse_content_stream,
 )
 
-from . import settings
+from pikepdf.models.ctm import (
+    get_objects_with_ctm,
+)
+
 
 # Importing these will monkeypatch classes defined in C++ and register a new
 # pdfdoc codec
-from . import _methods, codec
-
 # While _cpphelpers is intended to be called from our C++ code only, explicitly
 # importing helps introspection tools like PyInstaller figure out that the module
 # is necessary.
-from . import _cpphelpers
-
-__libqpdf_version__ = _qpdf.qpdf_version()
+from pikepdf import _cpphelpers, _methods, codec  # noqa: F401, F841
+from pikepdf import settings
+from pikepdf import exceptions
 
+__libqpdf_version__: str = _core.qpdf_version()
 
 # Provide pikepdf.{open, new} -> pikepdf.Pdf.{open, new}
 open = Pdf.open  # pylint: disable=redefined-builtin
@@ -94,7 +96,57 @@ new = Pdf.new
 _exclude_from__all__ = {'open', 'new', 'codec', 'objects', 'jbig2'}
 
 __all__ = [
-    k
-    for k in locals().keys()
-    if not k.startswith('_') and k not in _exclude_from__all__
+    '__libqpdf_version__',
+    '__version__',
+    'AccessMode',
+    'Annotation',
+    'Array',
+    'AttachedFileSpec',
+    'ContentStreamInlineImage',
+    'ContentStreamInstruction',
+    'DataDecodingError',
+    'DeletedObjectError',
+    'DependencyError',
+    'Dictionary',
+    'Encryption',
+    'exceptions',
+    'ForeignObjectError',
+    'get_objects_with_ctm',
+    'HifiPrintImageNotTranscodableError',
+    'InvalidPdfImageError',
+    'Job',
+    'JobUsageError',
+    'make_page_destination',
+    'Matrix',
+    'models',
+    'Name',
+    'NameTree',
+    'NumberTree',
+    'Object',
+    'ObjectHelper',
+    'ObjectStreamMode',
+    'ObjectType',
+    'Operator',
+    'Outline',
+    'OutlineItem',
+    'OutlineStructureError',
+    'Page',
+    'PageLocation',
+    'parse_content_stream',
+    'PasswordError',
+    'Pdf',
+    'PdfError',
+    'PdfImage',
+    'PdfInlineImage',
+    'Permissions',
+    'Rectangle',
+    'settings',
+    'Stream',
+    'StreamDecodeLevel',
+    'String',
+    'Token',
+    'TokenFilter',
+    'TokenType',
+    'unparse_content_stream',
+    'UnsupportedImageTypeError',
 ]
